#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-6tTjyarEottE4mZ6OoWOPR
key:                  uri-bytestring-0.3.3.1-6tTjyarEottE4mZ6OoWOPR
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  615dae7a664f88c16b1a463866c41d5d
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/uri-bytestring-0.3.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-6tTjyarEottE4mZ6OoWOPR
depends:
    attoparsec-0.14.4-qc2ScMijHsIVylJ0k0iua base-4.18.2.1
    blaze-builder-0.4.4.1-3ZGNeeLUhPeI237uQ0tBgU bytestring-0.11.5.3
    containers-0.6.7 template-haskell-2.20.0.0
    th-lift-instances-0.1.20-DQ6wl7ibJJKHOpexOEAKT8

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

